@@ -1,20 +1,47 @@
 #include "RBGL.hpp"
-#include <boost/graph/betweenness_centrality.hpp>
+#include <boost/graph/graph_utility.hpp>
+
+
+using namespace boost;
+
+typedef adjacency_list<vecS, vecS, undirectedS,
+	// vertex properties
+        property<vertex_index_t, int, 
+    	property<vertex_centrality_t, double> >, 
+    	// edge properties
+    	property<edge_weight_t, double, 
+    	property<edge_centrality_t, double> > >
+    	BCGraph;
+
+// Explicit instantiation of template function max_element circumvents 
+// compiler error in llvm8 libc++
+typedef graph_traits<BCGraph>::edge_descriptor Edge;
+typedef graph_traits<BCGraph>::edge_iterator EdgeIterator;
+typedef property_map < BCGraph, edge_centrality_t >::type EdgeCentralityMap;
+typedef typename property_traits<EdgeCentralityMap>::value_type centrality_type;
+typedef indirect_cmp<EdgeCentralityMap, std::less<centrality_type> > EdgeCentralityCompare;
+      
+EdgeIterator
+max_element(EdgeIterator __first, EdgeIterator __last, EdgeCentralityCompare __comp)
+{
+    if (__first != __last)
+    {
+        EdgeIterator __i = __first;
+        while (++__i != __last)
+            if (__comp(*__first, *__i))
+                __first = __i;
+    }
+    return __first;
+}
+
 #include <boost/graph/bc_clustering.hpp>
+#include <boost/graph/betweenness_centrality.hpp>
+
+
 
 extern "C"
 {
-	using namespace boost;
 
-   	typedef adjacency_list<vecS, vecS, undirectedS,
-    		// vertex properties
-                property<vertex_index_t, int, 
-    		property<vertex_centrality_t, double> >, 
-    		// edge properties
-    		property<edge_weight_t, double, 
-    		property<edge_centrality_t, double> > >
-    		BCGraph;
-	typedef graph_traits<BCGraph>::edge_descriptor Edge;
 
 	SEXP BGL_brandes_betweenness_centrality(SEXP num_verts_in, 
 		SEXP num_edges_in, SEXP R_edges_in, SEXP R_weights_in)
@@ -123,6 +150,9 @@ extern "C"
 			clustering_threshold(threshold, g, normalize),
 			get(edge_centrality, g));
 
+		// betweenness_centrality_clustering(g,
+		// 	clustering_threshold(threshold, g, normalize));
+
 		SEXP anslst, cnt, bcvlst, bcelst;
 		PROTECT(anslst = Rf_allocVector(VECSXP,3));
 		PROTECT(cnt = Rf_allocVector(INTSXP, 1));
